@@ -35,7 +35,7 @@ def local_train(dir, docker_tag, image_name):
     :param docker_tag: [str], the Docker tag for the image
     :param image_name: [str], The name of the Docker image
     """
-    sagify_module_path = os.path.join(dir, 'sagify_base')
+    sagify_module_path = os.path.join(dir, 'container')
     local_train_script_path = os.path.join(sagify_module_path, 'local_test', 'train_local.sh')
     test_path = os.path.join(sagify_module_path, 'local_test', 'test_dir')
 
@@ -81,7 +81,7 @@ def local_deploy(dir, docker_tag, image_name):
     :param docker_tag: [str], the Docker tag for the image
     :param image_name: [str], The name of the Docker image
     """
-    sagify_module_path = os.path.join(dir, 'sagify_base')
+    sagify_module_path = os.path.join(dir, 'container')
     local_deploy_script_path = os.path.join(sagify_module_path, 'local_test', 'deploy_local.sh')
     test_path = os.path.join(sagify_module_path, 'local_test', 'test_dir')
 
@@ -105,7 +105,7 @@ def get_local_container_ids(dir, docker_tag, image_name):
     :param docker_tag: [str], the Docker tag for the image
     :param image_name: [str], The name of the Docker image
     """
-    sagify_module_path = os.path.join(dir, 'sagify_base')
+    sagify_module_path = os.path.join(dir, 'container')
     local_deploy_script_path = os.path.join(sagify_module_path, 'local_test', 'deploy_local.sh')
     test_path = os.path.join(sagify_module_path, 'local_test', 'test_dir')
 
@@ -129,7 +129,7 @@ def local_deploy_detached(dir, docker_tag, image_name):
     :param docker_tag: [str], the Docker tag for the image
     :param image_name: [str], The name of the Docker image
     """
-    sagify_module_path = os.path.join(dir, 'sagify_base')
+    sagify_module_path = os.path.join(dir, 'container')
     local_deploy_script_path = os.path.join(sagify_module_path, 'local_test', 'deploy_local.sh')
     test_path = os.path.join(sagify_module_path, 'local_test', 'test_dir')
 
@@ -241,4 +241,4 @@ def run_predict(script_path: str, host: str, payload: str, content_type: str):
         pretty_output = result.stdout
     logger.info(pretty_output)
     logger.info("\nPrediction Complete! ヽ(´▽`)/")
-    return pretty_output
\ No newline at end of file
+    return pretty_output
