@@ -128,6 +128,7 @@ class SagifyConfigManager(BaseConfigManager):
         self.ask_for_container_dir_name()
         self.ask_for_requirements_file_name()
         self.ask_for_python_version()
+        self.ask_for_path_to_template_dir()
 
     def ask_for_image_name(self):
         """prompt user for image name
@@ -151,7 +152,7 @@ class SagifyConfigManager(BaseConfigManager):
         """
         platform_name = click.prompt(
             text="Set your platform name:",
-            default='sagemaker'
+            default='bare'
         )
 
         self.config.update({
@@ -166,7 +167,7 @@ class SagifyConfigManager(BaseConfigManager):
         """
         container_dir_name = click.prompt(
             text="Set your container dir name:",
-            default='sagify_base'
+            default='container'
         )
 
         self.config.update({
@@ -228,19 +229,22 @@ class SagifyConfigManager(BaseConfigManager):
             'python_version':python_version
         })
 
-    def ask_for_development_container_suffix(self):
+    def ask_for_path_to_template_dir(self):
         """prompt user for platform name
 
         Returns:
             return: platform name
         """
-        dev_container_suffix = click.prompt(
-            text="Set your dev container suffix:",
-            default='dev'
+        template_dir = click.prompt(
+            text="Set your template directory:",
+            default=""
         )
 
+        if template_dir == "":
+            template_dir = None
+
         self.config.update({
-            'dev_container_suffix':dev_container_suffix
+            'template_dir':template_dir
         })
 
     def get_config(self) -> dict:
