@@ -13,7 +13,7 @@ import pkg_resources
 
 _ = pkg_resources.get_distribution('mldock')
 
-from mldock.platform_helpers.gcp.environment import Environment
+from mldock.platform_helpers.environment import Environment
 from src.container.training.startup import logger
 
 def str2bool(arg_value: str) -> bool:
